/*
 * Device configuration.
 *
 * Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CONFIG_H__
#define __CONFIG_H__

#include "pic32.h"

/*
Set the oscillator to be the FRC oscillator with PLL, with peripheral clock
divided by 2 (FPBDIV), and FRCDIV+PLL selected (FNOSC).

The watchdog timer (FWDTEN) is also disabled.

The secondary oscillator pin (FSOSCEN) is disabled to avoid pin conflicts with
RPB4.
*/

#define DEVCFG1_CONFIG  (DEVCFG1_FWDTEN_OFF | DEVCFG1_FPBDIV_2 | \
                        DEVCFG1_OSCIOFNC_OFF | DEVCFG1_FSOSCEN_OFF | \
                        DEVCFG1_FNOSC_FRCDIV_PLL)

/*
Set the FRC oscillator PLL function with an input division of 2, an output
division of 2, a multiplication of 24, yielding a multiplication of 6.

The FRC is apparently at 8MHz but enforces input division of 2 to produce a
frequency in the acceptable range from 4MHz to 5MHz for the PLL:

8MHz / 2 = 4MHz

Multiplication and output division should produce a system clock of 48MHz:

4MHz * 24 / 2 = 48MHz
*/

#define DEVCFG2_CONFIG  (DEVCFG2_FPLLODIV_2 | DEVCFG2_FPLLMUL_24 | \
                        DEVCFG2_FPLLIDIV_2)

/*
The peripheral clock frequency (FPB) will be 24MHz given the above DEVCFG1 and
DEVCFG2 settings.
*/

#define FPB             24000000

#endif /* __CONFIG_H__ */
